# man page: https://rycee.gitlab.io/home-manager/options.html

{ nixpkgs, self }:
{ config, pkgs, lib, ... }: with lib; {
  
  nixpkgs.overlays = [ self.overlay ];

  imports = [ ./steam ./desktop ];

  home = {
    stateVersion = "21.11"; # No tocar esto
    username = "fabian";
    homeDirectory = "/home/fabian";
    packages = import ./path.nix pkgs;
    sessionVariables = {
      "EDITOR" = "nvim";
      "TERMINAL" = "kitty";
    };
    file = {
      ".shenvs".text = let
        keeps = { gcKeep ? [] }: concatStringsSep "\n" (map toString gcKeep);
      in keeps (import ../shenvs/config.nix pkgs.local.shenvs);
    };
    keyboard = {
      layout = "us,latam";
      options = [ "grp:alt_shift_toggle" ];
    };
  };

  systemd.user.tmpfiles.rules = [
    "d %t/tmp 0700 fabian fabian 24h"
  ];

  nix.registry."system".to = {
    type = "path";
    path = "/home/fabian/nix";
  };

  nix.registry."nixpkgs".flake = nixpkgs;

  nixpkgs.config.allowUnfree = true;

  programs.home-manager.enable = true;
  programs.neovim.enable = true;
  programs.zsh = {
    enable = true;
    enableSyntaxHighlighting = true;
    initExtra = import ./zshrc.nix pkgs;
  };

  programs.kitty = {
    enable = true;
    extraConfig = import ./kitty.conf.nix;
  };

  programs.tmux = {
    enable = true;
    aggressiveResize = true;
    clock24 = true;
    escapeTime = 10;
    terminal = "xterm-256color";
    keyMode = "emacs";

    extraConfig = ''
    set -g mouse on
    set -ga update-environment " LIFT_PID"
    set -g set-titles on
    set -g renumber-windows on
    set -sa terminal-overrides ',xterm-termite:RGB'
    set -g status-right "#{?window_bigger,[#{window_offset_x}#,#{window_offset_y}] ,} %H:%M %d-%b-%y"
      '';
  };

  # configurable = [ neovim keyboardlayout pulsaudio rofi ];

  programs.vscode = {
    enable = true;
    package = pkgs.vscodium;
    userSettings = import ./codium.nix;
    haskell = {
      enable = true;
      hie.enable = false;
    };

    mutableExtensionsDir = false;
    extensions = (with pkgs.vscode-extensions; [
      bbenoist.nix
      # justusadam.language-haskell
      ms-toolsai.jupyter
      ms-vscode.cpptools
      # github.copilot
   ]) ++ (with pkgs.local.vscode-extensions; [
      laurenttreguier.vscode-simple-icons
      rust-lang.rust
      sirtori.indenticator
    ]);
  };

  programs.git = {
    enable = true;
    userEmail = "fabian@cluster451.org";
    userName = "Fabián Montero";
    signing.key = "E77A808BF9A955D668EEEA6473FA9C9CB5F0249B";
  };

  programs.steam.enable = true;
}

